xz

package module
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2021 License: Unlicense Imports: 7 Imported by: 1

README

Xz

Package xz implements XZ decompression natively in Go. Documentation at:

https://pkg.go.dev/github.com/89z/xz.

If you need compression as well as decompression, you might want to look at https://github.com/ulikunitz/xz.

This Go package is a modified version of XZ Embedded http://tukaani.org/xz/embedded.html.

The contents of the testdata directory are modified versions of the test files from XZ Utils http://tukaani.org/xz/.

All the files in this package have been written by Michael Cross, Lasse Collin and/or Igor PavLov.

Method = LZMA2:23 CRC64
Method = LZMA2:23 NoCheck

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewReader

func NewReader(r io.Reader) (io.Reader, error)

NewReader creates a new reader reading from r. The decompressor will use an LZMA2 dictionary size up to defaultDictMax bytes in size.

Due to internal buffering, the reader may read more data than necessary from r.

Types

This section is empty.

Jump to