Documentation
¶
Index ¶
Constants ¶
const DefaultDictMax = 1 << 26 // 64 MiB
DefaultDictMax is the default maximum dictionary size in bytes used by the decoder. This value is sufficient to decompress files created with XZ Utils "xz -9".
Variables ¶
This section is empty.
Functions ¶
func NewReader ¶
NewReader creates a new reader reading from r. The decompressor will use an LZMA2 dictionary size up to dictMax bytes in size. Passing a value of zero sets dictMax to DefaultDictMax. If an individual XZ stream requires a dictionary size greater than dictMax in order to decompress, Read will return errMemlimit.
If NewReader is passed a value of nil for r then a reader is created such that all read attempts will return io.EOF. This is useful if you just want to allocate memory for a reader which will later be initialized with Reset.
Due to internal buffering, the reader may read more data than necessary from r.
Types ¶
This section is empty.